/* VersCheck GUI includes */
#include "version.h"

#include <clib/alib_protos.h>
#include <clib/asl_protos.h>
#include <clib/battclock_protos.h>
#include <clib/battmem_protos.h>
#include <clib/cia_protos.h>
#include <clib/commodities_protos.h>
#include <clib/console_protos.h>
#include <clib/diskfont_protos.h>
#include <clib/dos_protos.h>
#include <clib/exec_protos.h>
#include <clib/expansion_protos.h>
#include <clib/gadtools_protos.h>
#include <clib/graphics_protos.h>
#include <clib/icon_protos.h>
#include <clib/iffparse_protos.h>
#include <clib/input_protos.h>
#include <clib/intuition_protos.h>
#include <clib/keymap_protos.h>
#include <clib/layers_protos.h>
#include <clib/macros.h>
#include <clib/mathffp_protos.h>
#include <clib/mathieeedoubbas_protos.h>
#include <clib/mathieeedoubtrans_protos.h>
#include <clib/mathieeesingbas_protos.h>
#include <clib/mathieeesingtrans_protos.h>
#include <clib/mathtrans_protos.h>
#include <clib/misc_protos.h>
#include <clib/potgo_protos.h>
#include <clib/ramdrive_protos.h>
#include <clib/timer_protos.h>
#include <clib/translator_protos.h>
#include <clib/utility_protos.h>
#include <clib/wb_protos.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <time.h>
#include <stat.h>
#include <signal.h>
#include <libraries/dos.h>
#include <libraries/dosextens.h>
#include <libraries/diskfont.h>
#include <libraries/intuisup.h>
#include <intuition/intuition.h>
#include <dos/dos.h>
#include <dos/dosextens.h>
#include <dos/datetime.h>
#include <exec/types.h>
#include <exec/io.h>
#include <exec/exec.h>
#include <exec/execbase.h>
#include <exec/ports.h>
#include <exec/tasks.h>
#include <exec/memory.h>
#include <devices/console.h>
#include <devices/conunit.h>
#include <devices/serial.h>
#include <devices/narrator.h>
#include <devices/timer.h>
#include <graphics/text.h>

#include "VersCheckGUI_protos.h"
#include "VERS.h"

#define RENDER_INFO_FLAGS  1
#define OPEN_WINDOW_FLAGS  0

#define WINDOW_LEFT_EDGE   0
#define WINDOW_TOP_EDGE    0
#define WINDOW_WIDTH       435
#define WINDOW_HEIGHT      230

STATIC struct NewWindow  verscheck_new_window =
{
	WINDOW_LEFT_EDGE, WINDOW_TOP_EDGE, WINDOW_WIDTH, WINDOW_HEIGHT,
	1, 2,
	CLOSEWINDOW | MENUPICK | GADGET_IDCMP_FLAGS_ALL,
	WINDOWCLOSE | WINDOWDRAG | WINDOWDEPTH | RMBTRAP,

	NULL, NULL,
	(UBYTE *)"VersCheck GUI",
	NULL, NULL,
	-1, -1, -1, -1,
	WBENCHSCREEN
};

#define VERSCHECK_BORDER_FLAGS   0

STATIC struct BorderData  verscheck_border_data[] =
{
	{
		2, 144, 16, 182, 127
	},
	{
		INTUISUP_DATA_END
	}
};

STATIC struct TextAttr  verscheck_text_attr[] =
{
	{
		(STRPTR)"xen.font", 9, FS_NORMAL, FPF_ROMFONT
	}
};

#define VERSCHECK_GADGET_LIBCHECK	0
#define VERSCHECK_GADGET_ALL		1
#define VERSCHECK_GADGET_SYSINFO	2
#define VERSCHECK_GADGET_FULLPATH	3
#define VERSCHECK_GADGET_MERGE		4
#define VERSCHECK_GADGET_NOREQ		5
#define VERSCHECK_GADGET_HTML		6
#define VERSCHECK_GADGET_VERBOSE	7
#define VERSCHECK_GADGET_POWEREXE	8
#define VERSCHECK_GADGET_IMAGES		9
#define VERSCHECK_GADGET_SUFFIX		10
#define VERSCHECK_GADGET_LIST		11
#define VERSCHECK_GADGET_OUTFILE	12
#define VERSCHECK_GADGET_FILEDIR	13
#define VERSCHECK_GADGET_START		14
#define VERSCHECK_GADGET_STARTALL	15

STATIC BYTE *verscheck_gadget1_text_array[] =
{
	"Library's",
	"Devices",
	"Datatypes",
	"MUI",
	"Handler",
	"Classes .class",
	"Classes .image",
	"Classes .gadget",
	"Classes .codec",
	"Classes .decoder",
	"Free config",
	"None",
	NULL
};

STATIC BYTE *verscheck_powerexe_text_array[] =
{
	"No PPC",
	"PowerUP",
	"WarpOS",
	"PPC + WOS",
	NULL
};

STATIC BYTE *verscheck_images_text_array[] =
{
	"No images",
	"IFF",
	"Images",
	NULL
};

STATIC struct GadgetData  verscheck_gadget_data[] =
{
	{
		3, 144, 3, 16, 138, 127,
		"_compare with", &verscheck_text_attr[0],
		{
			1, 0, &verscheck_gadget1_text_array[0]
		}
	},
	{
		2, 144, 150, 27, 21, 11,
		"_all subdirs", &verscheck_text_attr[0],
		{
			1, 0, (VOID *)0
		}
	},
	{
		2, 144, 150, 43, 21, 11,
		"_show systeminformation", &verscheck_text_attr[0],
		{
			1, 0, (VOID *)0
		}
	},
	{
		2, 144, 150, 59, 21, 11,
		"_full path", &verscheck_text_attr[0],
		{
			1, 0, (VOID *)0
		}
	},
	{
		2, 144, 150, 75, 21, 11,
		"_merge outputfiles", &verscheck_text_attr[0],
		{
			0, 0, (VOID *)0
		}
	},
	{
		2, 144, 150, 91, 21, 11,
		"_no requester", &verscheck_text_attr[0],
		{
			0, 0, (VOID *)0
		}
	},
	{
		2, 144, 150, 107, 21, 11,
		"force _HTML output", &verscheck_text_attr[0],
		{
			1, 0, (VOID *)0
		}
	},
	{
		2, 144, 150, 123, 21, 11,
		"_verbose", &verscheck_text_attr[0],
		{
			1, 0, (VOID *)0
		}
	},
	{
		3, 144, 331, 16, 96, 47,
		"ch_eck", &verscheck_text_attr[0],
		{
			1, 3, &verscheck_powerexe_text_array[0]
		}
	},
	{
		3, 144, 331, 106, 96, 37,
		"_list", &verscheck_text_attr[0],
		{
			1, 0, &verscheck_images_text_array[0]
		}
	},
	{
		4, 80, 200, 147, 227, 20,
		"Suffi_x", &verscheck_text_attr[0],
		{
			30, 0, ""
		}
	},
	{
		4, 80, 200, 167, 227, 18,
		"C_ompare list", &verscheck_text_attr[0],
		{
			120, 0, ""
		}
	},
	{
		4, 80, 200, 187, 227, 18,
		"Out_put file", &verscheck_text_attr[0],
		{
			120, 0, ""
		}
	},
	{
		4, 80, 200, 207, 227, 18,
		"file/_dir", &verscheck_text_attr[0],
		{
			120, 0, ""
		}
	},
	{
		1, 1040, 4, 150, 111, 25,
		"S_tart VersCheck", &verscheck_text_attr[0],
		{
			0, 0, (VOID *)0
		}
	},
	{
		1, 1040, 4, 180, 111, 25,
		"Sta_rt all tests", &verscheck_text_attr[0],
		{
			0, 0, (VOID *)0
		}
	},
	{
		INTUISUP_DATA_END
	}
};

struct	Library	*IntuiSupBase	=	NULL;
struct	Window	*win			=	NULL;
APTR	ri						=	NULL;
APTR	gl						=	NULL;

UBYTE	suffix[32];
UBYTE	chklst[128];
UBYTE	ofname[128];
UBYTE	dirnam[128];
